Description Kapferer data sets

This is an extended version of the Kapferer data set available at the Pajek-UCINET list of datasets.

## KAPFERER TAILOR SHOP

### Description

Four 39×39 matrices

> `KAPFTS1.dat` symmetric, binary
> `KAPFTS2.dat` symmetric, binary
> `KAPFTI1.dat` non-symmetric, binary
> `KAPFTI2.dat` non-symmetric, binary

Two combined squared matrices (can be used e.g. for the program BLOCKS; see Nowicki & Snijders, JASA 2001):

> `KAPF1.dat` combined coding: (2*kapfts1.dat) + kapfti1.dat
> `KAPF2.dat` combined coding: (2*kapfts2.dat) + kapfti2.dat

Two attributes files

> `kapfa_stat.dat` job status in categories according to Kapferer (1972); see below
> `kapfat.dat` first variable is a dummy for Lyashi (the most central individual); second variable indicates workers in high status jobs.

### Background

Bruce Kapferer (1972) observed interactions in a tailor shop in Zambia (then Northern Rhodesia) over a period of ten months. His focus was the changing patterns of alliance among workers during extended negotiations for higher wages.

The matrices represent two different types of interaction, recorded at two different times (seven months apart) over a period of one month. `KAPFTI1.dat` and `KAPFTI2.dat` record the "instrumental" (work- and assistance-related) interactions at the two times; `KAPFTS1.dat` and `KAPFTS2.dat` the "sociational" (friendship, socioemotional) interactions.

The data are particularly interesting since an abortive strike occurred after the first set of observations, and a successful strike took place after the second.

### Coding

The employees' occupational categories were, in the order of their prestige according to a survey among employees (Kapferer, 1972 p. 55-59):

1. head tailor (worker nr 19),
2. cutter (16),
3. line 1 tailor (1-3, 5-7, 9, 11-14, 21, 24)
4. button machiner (25-26)
5. line 3 tailor (8, 15, 20, 22-23, 27-28)
6. ironer (29, 33, 39)
7. cotton boy (30-32, 34-38)
8. line 2 tailor (4, 10, 17-18).

These are the codes used in `kapfa_stat.dat`.

### Reference

- Kapferer B. (1972). Strategy and transaction in an African factory. Manchester: Manchester University Press.